@@ -9,32 +9,36 @@ indices_list = data_io.get_indiceslist()
 indices_list.sort()
 print(indices_list)
 
+# sample = data_io.sample_loader(indices_list[0], load_seg=True, load_pred=False)
+# print(sample.img_data.shape, sample.details["spacing"])
+
 # Specify subfunctions for preprocessing
 from miscnn.processing.subfunctions import *
-sf = [Resampling((9,9,9)), Padding((32,32,32), shape_must_be_divisible_by=16)]
+# sf = [Resampling((9,9,9)), Padding((32,32,32), shape_must_be_divisible_by=16)]
+sf = [Normalization(mode="grayscale")]
 
 from miscnn import Preprocessor
 pp = Preprocessor(data_io, data_aug=None, batch_size=1, subfunctions=sf,
                   prepare_subfunctions=True, prepare_batches=False,
                   analysis="fullimage", patch_shape=(128,128,128))
 
-# # Initialize Keras Data Generator for generating batches
-# from miscnn.neural_network.data_generator import DataGenerator
-# dataGen = DataGenerator(indices_list[2:4], pp, training=True, validation=False,
-#                         shuffle=False)
+# Initialize Keras Data Generator for generating batches
+from miscnn.neural_network.data_generator import DataGenerator
+dataGen = DataGenerator(indices_list[2:4], pp, training=True, validation=False,
+                        shuffle=False)
+
+for img, seg in dataGen:
+    print(img.min(), img.max())
+    #print(batch.shape)
+
+# from miscnn.neural_network.model import Neural_Network
+# model = Neural_Network(preprocessor=pp)
+# # model.train(indices_list[2:4], epochs=2, iterations=5, callbacks=[])
 #
-# for img, seg in dataGen:
-#     print(img.shape)
-#     #print(batch.shape)
-
-from miscnn.neural_network.model import Neural_Network
-model = Neural_Network(preprocessor=pp)
-# model.train(indices_list[2:4], epochs=2, iterations=5, callbacks=[])
-
-pred = model.predict(indices_list[2:3], direct_output=True)
-
-import numpy as np
-print(np.asarray(pred).shape)
+# pred = model.predict(indices_list[2:3], direct_output=True)
+#
+# import numpy as np
+# print(np.asarray(pred).shape)
 
 # sample = data_io.sample_loader("case_00000:#:89", load_seg=True, load_pred=True)
 # print(sample.img_data.shape, sample.seg_data.shape, sample.pred_data.shape)
